summaryrefslogtreecommitdiffstats
path: root/src/kernel/qstyle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qstyle.cpp')
-rw-r--r--src/kernel/qstyle.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/kernel/qstyle.cpp b/src/kernel/qstyle.cpp
index 5eda7a77..9222e373 100644
--- a/src/kernel/qstyle.cpp
+++ b/src/kernel/qstyle.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing retquirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -62,7 +62,7 @@ public:
\ingroup appearance
Some TQStyle functions take an optional argument specifying extra
- information that is retquired for a paritical primitive or control.
+ information that is required for a paritical primitive or control.
So that the TQStyle class can be extended, TQStyleOption is used to
provide a variable-argument for these options.
@@ -482,9 +482,9 @@ void TQStyle::unPolish( TQApplication*)
/*!
\overload
- The style may have certain retquirements for color palettes. In
+ The style may have certain requirements for color palettes. In
this function it has the chance to change the palette according to
- these retquirements.
+ these requirements.
\sa TQPalette, TQApplication::setPalette()
*/
@@ -947,7 +947,7 @@ void TQStyle::drawItem( TQPainter *p, const TQRect &r,
The \a widget argument is a pointer to a TQWidget or one of its
subclasses. The widget can be cast to the appropriate type based
on the value of \a element. The \a opt argument can be used to
- pass extra information retquired when drawing the ControlElement.
+ pass extra information required when drawing the ControlElement.
Note that \a opt may be the default value even for ControlElements
that can make use of the extra options. See the table below for
the appropriate \a widget and \a opt usage:
@@ -1303,7 +1303,7 @@ void TQStyle::drawItem( TQPainter *p, const TQRect &r,
The \a widget argument is a pointer to a TQWidget or one of its
subclasses. The widget can be cast to the appropriate type based
on the value of \a control. The \a opt argument can be used to
- pass extra information retquired when drawing the ComplexControl.
+ pass extra information required when drawing the ComplexControl.
Note that \a opt may be the default value even for ComplexControls
that can make use of the extra options. See the table below for
the appropriate \a widget and \a opt usage:
@@ -1398,7 +1398,7 @@ void TQStyle::drawItem( TQPainter *p, const TQRect &r,
The \a widget argument is a pointer to a TQWidget or one of its
subclasses. The widget can be cast to the appropriate type based
on the value of \a control. The \a opt argument can be used to
- pass extra information retquired when drawing the ComplexControl.
+ pass extra information required when drawing the ComplexControl.
Note that \a opt may be the default value even for ComplexControls
that can make use of the extra options. See drawComplexControl()
for an explanation of the \a widget and \a opt arguments.
@@ -1413,7 +1413,7 @@ void TQStyle::drawItem( TQPainter *p, const TQRect &r,
widget argument is a pointer to a TQWidget or one of its
subclasses. The widget can be cast to the appropriate type based
on the value of \a control. The \a opt argument can be used to
- pass extra information retquired when drawing the ComplexControl.
+ pass extra information required when drawing the ComplexControl.
Note that \a opt may be the default value even for ComplexControls
that can make use of the extra options. See drawComplexControl()
for an explanation of the \a widget and \a opt arguments.
@@ -1447,7 +1447,7 @@ void TQStyle::drawItem( TQPainter *p, const TQRect &r,
\value PM_MDIFrameWidth frame width of an MDI window.
\value PM_MDIMinimizedWidth width of a minimized MSI window.
- \value PM_MaximumDragDistance Some feels retquire the scrollbar or
+ \value PM_MaximumDragDistance Some feels require the scrollbar or
other sliders to jump back to the original position when the
mouse pointer is too far away while dragging. A value of -1
disables this behavior.
@@ -1592,7 +1592,7 @@ void TQStyle::drawItem( TQPainter *p, const TQRect &r,
The \a widget argument is a pointer to a TQWidget or one of its
subclasses. The widget can be cast to the appropriate type based
on the value of \a contents. The \a opt argument can be used to
- pass extra information retquired when calculating the size. Note
+ pass extra information required when calculating the size. Note
that \a opt may be the default value even for ContentsTypes that
can make use of the extra options. See the table below for the
appropriate \a widget and \a opt usage:
@@ -1815,7 +1815,7 @@ void TQStyle::drawItem( TQPainter *p, const TQRect &r,
Returns a pixmap for \a stylepixmap.
- The \a opt argument can be used to pass extra information retquired
+ The \a opt argument can be used to pass extra information required
when drawing the ControlElement. Note that \a opt may be the
default value even for StylePixmaps that can make use of the extra
options. Currently, the \a opt argument is unused.
@@ -18,7 +18,7 @@
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please